@@ -250,7 +250,7 @@ public abstract class ListCore extends UserAbstraction {
         notallowedOrReplace.put("Gui_spam_filter_enabled", "GUI_Spam_filter_capabilities_enabled");
         final ArrayList<MethodAndNames> methArrayList = getGetters(methods, notallowedOrReplace);
 
-        final ArrayList<String> columnnames = new ArrayList<String>();
+        final ArrayList<String> columnnames = new ArrayList<String>(32);
         for (final MethodAndNames methodandnames : methArrayList) {
             columnnames.add(methodandnames.getName());
         }
@@ -286,6 +286,8 @@ public abstract class ListCore extends UserAbstraction {
             columnnames.add(UserAbstraction.OPT_ACCESS_PUBLICATION);
             columnnames.add(UserAbstraction.OPT_ACCESS_ACTIVE_SYNC);
             columnnames.add(UserAbstraction.OPT_ACCESS_USM);
+            columnnames.add(UserAbstraction.OPT_DISABLE_GAB);
+            columnnames.add(UserAbstraction.OPT_ACCESS_PUBLIC_FOLDER_EDITABLE);
 
         }
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
@@ -344,6 +346,8 @@ public abstract class ListCore extends UserAbstraction {
             datarow.add(String.valueOf(access.isPublication()));
             datarow.add(String.valueOf(access.isActiveSync()));
             datarow.add(String.valueOf(access.isUSM()));
+            datarow.add(String.valueOf(access.isGlobalAddressBookDisabled()));
+            datarow.add(String.valueOf(access.isPublicFolderEditable()));
             data.add(datarow);
             printExtensionsError(user);
         }
