@@ -49,6 +49,8 @@
 
 package com.openexchange.admin.rmi.dataobjects;
 
+import java.io.IOException;
+import java.io.ObjectStreamException;
 import java.io.Serializable;
 import java.lang.reflect.Field;
 
@@ -124,6 +126,9 @@ public class UserModuleAccess implements Serializable {
 
     private boolean USM = true;
 
+    private boolean GlobalAddressBookDisabled = false;
+
+    private boolean PublicFolderEditable = true;
 
     /**
      * Creates a new instance of UserModuleAccess
@@ -132,49 +137,6 @@ public class UserModuleAccess implements Serializable {
         super();
     }
 
-    /**
-     * @param calendar
-     * @param contacts
-     * @param delegateTask
-     * @param editPublicFolders
-     * @param forum
-     * @param ical
-     * @param infostore
-     * @param pinboardWrite
-     * @param projects
-     * @param readCreateSharedFolders
-     * @param rssBookmarks
-     * @param rssPortal
-     * @param syncml
-     * @param tasks
-     * @param vcard
-     * @param webdav
-     * @param webdavXml
-     * @param webmail
-     * @deprecated
-     */
-    @Deprecated
-    public UserModuleAccess(final boolean calendar, final boolean contacts, final boolean delegateTask, final boolean editPublicFolders, final boolean forum, final boolean ical, final boolean infostore, final boolean pinboardWrite, final boolean projects, final boolean readCreateSharedFolders, final boolean rssBookmarks, final boolean rssPortal, final boolean syncml, final boolean tasks, final boolean vcard, final boolean webdav, final boolean webdavXml, final boolean webmail) {
-        super();
-        this.calendar = calendar;
-        this.contacts = contacts;
-        this.delegateTask = delegateTask;
-        this.editPublicFolders = editPublicFolders;
-        this.forum = forum;
-        this.ical = ical;
-        this.infostore = infostore;
-        this.PinboardWrite = pinboardWrite;
-        this.Projects = projects;
-        this.readCreateSharedFolders = readCreateSharedFolders;
-        this.RssBookmarks = rssBookmarks;
-        this.RssPortal = rssPortal;
-        this.Syncml = syncml;
-        this.Tasks = tasks;
-        this.Vcard = vcard;
-        this.Webdav = webdav;
-        this.WebdavXml = webdavXml;
-        this.Webmail = webmail;
-    }
 
     /**
      * Enable all modules
@@ -207,6 +169,8 @@ public class UserModuleAccess implements Serializable {
         this.Publication = true;
         this.ActiveSync = true;
         this.USM = true;
+        this.GlobalAddressBookDisabled = false;
+        this.PublicFolderEditable = true;
     }
 
     /**
@@ -240,6 +204,8 @@ public class UserModuleAccess implements Serializable {
         this.Publication = false;
         this.ActiveSync = false;
         this.USM = false;
+        this.GlobalAddressBookDisabled = true;
+        this.PublicFolderEditable = false;
     }
 
     public boolean getEditGroup() {
@@ -548,7 +514,7 @@ public class UserModuleAccess implements Serializable {
         return ActiveSync;
     }
 
-    public void setActiveSync(boolean activeSync) {
+    public void setActiveSync(final boolean activeSync) {
         this.ActiveSync = activeSync;
     }
 
@@ -556,10 +522,26 @@ public class UserModuleAccess implements Serializable {
         return USM;
     }
 
-    public void setUSM(boolean val) {
+    public void setUSM(final boolean val) {
         this.USM = val;
     }
 
+    public boolean isGlobalAddressBookDisabled() {
+        return GlobalAddressBookDisabled;
+    }
+
+    public void setGlobalAddressBookDisabled(final boolean val) {
+        this.GlobalAddressBookDisabled = val;
+    }
+
+    public boolean isPublicFolderEditable() {
+        return PublicFolderEditable;
+    }
+
+    public void setPublicFolderEditable(final boolean publicFolderEditable) {
+        PublicFolderEditable = publicFolderEditable;
+    }
+
     @Override
     public String toString() {
         final StringBuilder ret = new StringBuilder();
